@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.6.2"
+#define PYO_VERSION "0.6.6"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -42,6 +42,7 @@
 #define TYPE_O_FO "O|fO"
 #define TYPE__OF "|Of"
 #define TYPE_O_FOO "O|fOO"
+#define TYPE_O_FIOO "O|fiOO"
 #define TYPE_I_FFOO "i|ffOO"
 #define TYPE_I_FFFOO "i|fffOO"
 #define TYPE_I_FFFIOO "i|fffiOO"
@@ -71,6 +72,7 @@
 #define TYPE__FIIOO "|fiiOO"
 #define TYPE_O_OFOO "O|OfOO"
 #define TYPE_O_IFFO "O|iffO"
+#define TYPE_O_FFFFIOO "O|ffffiOO"
 #define TYPE_OO_FOO "OO|fOO"
 #define TYPE_OO_FFOO "OO|ffOO"
 #define TYPE_O_IFIOO "O|ifiOO"
@@ -117,6 +119,7 @@
 #define TYPE_O_FO "O|dO"
 #define TYPE__OF "|Od"
 #define TYPE_O_FOO "O|dOO"
+#define TYPE_O_FIOO "O|diOO"
 #define TYPE_I_FFOO "i|ddOO"
 #define TYPE_I_FFFOO "i|dddOO"
 #define TYPE_I_FFFIOO "i|dddiOO"
@@ -146,6 +149,7 @@
 #define TYPE__FIIOO "|diiOO"
 #define TYPE_O_OFOO "O|OdOO"
 #define TYPE_O_IFFO "O|iddO"
+#define TYPE_O_FFFFIOO "O|ddddiOO"
 #define TYPE_OO_FOO "OO|dOO"
 #define TYPE_OO_FFOO "OO|ddOO"
 #define TYPE_O_IFIOO "O|idiOO"
@@ -180,6 +184,10 @@
 #endif
 #endif
 
+#ifdef COMPILE_EXTERNALS
+#include "externalmodule.h"
+#endif
+
 extern PyTypeObject SineType;
 extern PyTypeObject SineLoopType;
 extern PyTypeObject FmType;
@@ -191,13 +199,16 @@ extern PyTypeObject RosslerAltType;
 extern PyTypeObject LorenzType;
 extern PyTypeObject LorenzAltType;
 extern PyTypeObject PhasorType;
+extern PyTypeObject SuperSawType;
 extern PyTypeObject PointerType;
 extern PyTypeObject TableIndexType;
 extern PyTypeObject LookupType;
 extern PyTypeObject TableReadType;
 extern PyTypeObject OscType;
 extern PyTypeObject OscLoopType;
+extern PyTypeObject OscTrigType;
 extern PyTypeObject OscBankType;
+extern PyTypeObject SumOscType;
 extern PyTypeObject PulsarType;
 extern PyTypeObject NoiseType;
 extern PyTypeObject PinkNoiseType;
@@ -209,7 +220,6 @@ extern PyTypeObject SfMarkerShufflerType;
 extern PyTypeObject SfMarkerShuffleType;
 extern PyTypeObject SfMarkerLooperType;
 extern PyTypeObject SfMarkerLoopType;
-
 extern PyTypeObject TrigType;
 extern PyTypeObject NextTrigType;
 extern PyTypeObject MetroType;
@@ -230,14 +240,11 @@ extern PyTypeObject ChangeType;
 extern PyTypeObject ThreshType;
 extern PyTypeObject PercentType;
 extern PyTypeObject TimerType;
-
 extern PyTypeObject ScoreType;
-
 extern PyTypeObject FaderType;
 extern PyTypeObject AdsrType;
 extern PyTypeObject LinsegType;
 extern PyTypeObject ExpsegType;
-
 extern PyTypeObject RandiType;
 extern PyTypeObject RandhType;
 extern PyTypeObject RandDurType;
@@ -247,12 +254,12 @@ extern PyTypeObject XnoiseType;
 extern PyTypeObject XnoiseMidiType;
 extern PyTypeObject XnoiseDurType;
 extern PyTypeObject UrnType;
-
 extern PyTypeObject BiquadType;
 extern PyTypeObject BiquadxType;
 extern PyTypeObject BiquadaType;
 extern PyTypeObject EQType;
 extern PyTypeObject ToneType;
+extern PyTypeObject AtoneType;
 extern PyTypeObject DCBlockType;
 extern PyTypeObject PortType;
 extern PyTypeObject AllpassType;
@@ -268,6 +275,7 @@ extern PyTypeObject BetweenType;
 extern PyTypeObject DegradeType;
 extern PyTypeObject CompressType;
 extern PyTypeObject GateType;
+extern PyTypeObject BalanceType;
 extern PyTypeObject DelayType;
 extern PyTypeObject SDelayType;
 extern PyTypeObject WaveguideType;
@@ -280,11 +288,9 @@ extern PyTypeObject IRWinSincType;
 extern PyTypeObject IRPulseType;
 extern PyTypeObject IRAverageType;
 extern PyTypeObject IRFMType;
-
 extern PyTypeObject GranulatorType;
 extern PyTypeObject LooperType;
 extern PyTypeObject HarmonizerType;
-
 extern PyTypeObject MidictlType;
 extern PyTypeObject CtlScanType;
 extern PyTypeObject CtlScan2Type;
@@ -295,7 +301,6 @@ extern PyTypeObject TouchinType;
 extern PyTypeObject PrograminType;
 extern PyTypeObject MidiAdsrType;
 extern PyTypeObject MidiDelAdsrType;
-
 extern PyTypeObject DummyType;
 extern PyTypeObject TriggerDummyType;
 extern PyTypeObject RecordType;
@@ -309,7 +314,6 @@ extern PyTypeObject SigType;
 extern PyTypeObject SigToType;
 extern PyTypeObject VarPortType;
 extern PyTypeObject InputFaderType;
-
 extern PyTypeObject HarmTableType;
 extern PyTypeObject ChebyTableType;
 extern PyTypeObject HannTableType;
@@ -317,6 +321,8 @@ extern PyTypeObject SincTableType;
 extern PyTypeObject WinTableType;
 extern PyTypeObject ParaTableType;
 extern PyTypeObject LinTableType;
+extern PyTypeObject LogTableType;
+extern PyTypeObject CosLogTableType;
 extern PyTypeObject CosTableType;
 extern PyTypeObject CurveTableType;
 extern PyTypeObject ExpTableType;
@@ -324,15 +330,16 @@ extern PyTypeObject SndTableType;
 extern PyTypeObject DataTableType;
 extern PyTypeObject NewTableType;
 extern PyTypeObject TableRecType;
+extern PyTypeObject TableRecTimeStreamType;
 extern PyTypeObject TableMorphType;
 extern PyTypeObject TrigTableRecType;
-
+extern PyTypeObject TrigTableRecTimeStreamType;
+extern PyTypeObject TablePutType;
 extern PyTypeObject NewMatrixType;
 extern PyTypeObject MatrixPointerType;
 extern PyTypeObject MatrixRecType;
 extern PyTypeObject MatrixRecLoopType;
 extern PyTypeObject MatrixMorphType;
-
 extern PyTypeObject OscSendType;
 extern PyTypeObject OscReceiveType;
 extern PyTypeObject OscReceiverType;
@@ -340,8 +347,8 @@ extern PyTypeObject OscDataSendType;
 extern PyTypeObject OscDataReceiveType;
 extern PyTypeObject OscListReceiveType;
 extern PyTypeObject OscListReceiverType;
-
 extern PyTypeObject TrigRandIntType;
+extern PyTypeObject TrigValType;
 extern PyTypeObject TrigRandType;
 extern PyTypeObject TrigChoiceType;
 extern PyTypeObject IterType;
@@ -351,22 +358,17 @@ extern PyTypeObject TrigExpsegType;
 extern PyTypeObject TrigFuncType;
 extern PyTypeObject TrigXnoiseType;
 extern PyTypeObject TrigXnoiseMidiType;
-
 extern PyTypeObject PatternType;
 extern PyTypeObject CallAfterType;
-
 extern PyTypeObject BandSplitterType;
 extern PyTypeObject BandSplitType;
 extern PyTypeObject FourBandMainType;
 extern PyTypeObject FourBandType;
-
 extern PyTypeObject HilbertMainType;
 extern PyTypeObject HilbertType;
-
 extern PyTypeObject FollowerType;
 extern PyTypeObject Follower2Type;
 extern PyTypeObject ZCrossType;
-
 extern PyTypeObject SPannerType;
 extern PyTypeObject SPanType;
 extern PyTypeObject PannerType;
@@ -377,7 +379,6 @@ extern PyTypeObject SelectorType;
 extern PyTypeObject VoiceManagerType;
 extern PyTypeObject MixerType;
 extern PyTypeObject MixerVoiceType;
-
 extern PyTypeObject PrintType;
 extern PyTypeObject SnapType;
 extern PyTypeObject InterpType;
@@ -389,7 +390,6 @@ extern PyTypeObject CentsToTranspoType;
 extern PyTypeObject TranspoToCentsType;
 extern PyTypeObject MToFType;
 extern PyTypeObject MToTType;
-
 extern PyTypeObject M_SinType;
 extern PyTypeObject M_CosType;
 extern PyTypeObject M_TanType;
@@ -403,7 +403,6 @@ extern PyTypeObject M_Atan2Type;
 extern PyTypeObject M_FloorType;
 extern PyTypeObject M_CeilType;
 extern PyTypeObject M_RoundType;
-
 extern PyTypeObject FFTMainType;
 extern PyTypeObject FFTType;
 extern PyTypeObject IFFTType;
@@ -415,6 +414,15 @@ extern PyTypeObject FrameAccumMainType;
 extern PyTypeObject FrameAccumType;
 extern PyTypeObject VectralMainType;
 extern PyTypeObject VectralType;
+extern PyTypeObject MinType;
+extern PyTypeObject MaxType;
+extern PyTypeObject Delay1Type;
+extern PyTypeObject RCOscType;
+extern PyTypeObject YinType;
+extern PyTypeObject SVFType;
+extern PyTypeObject AverageType;
+extern PyTypeObject CvlVerbType;
+extern PyTypeObject SpectrumType;
 
 /* Constants */
 #define E M_E
@@ -699,7 +707,7 @@ extern PyTypeObject VectralType;
  \
     return samples;
 
-/* Table remove DC */
+/* Table reverse */
 #define REVERSE \
     int i, j; \
     MYFLT tmp; \
@@ -713,6 +721,15 @@ extern PyTypeObject VectralType;
     Py_INCREF(Py_None); \
     return Py_None; \
 
+/* Table reset */
+#define TABLE_RESET \
+    int i; \
+    for (i=0; i<self->size; i++) { \
+        self->data[i] = 0.0; \
+    } \
+    Py_INCREF(Py_None); \
+    return Py_None; \
+
 /* Table remove DC */
 #define REMOVE_DC \
     int i; \
