@@ -85,20 +85,15 @@ class Biquad(PyoObject):
 
     """
     def __init__(self, input, freq=1000, q=1, type=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._q = q
         self._type = type
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, q, type, mul, add, lmax = convertArgsToLists(self._in_fader, freq, q, type, mul, add)
         self._base_objs = [Biquad_base(wrap(in_fader,i), wrap(freq,i), wrap(q,i), wrap(type,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'q', 'type', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -245,21 +240,16 @@ class Biquadx(PyoObject):
 
     """
     def __init__(self, input, freq=1000, q=1, type=0, stages=4, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._q = q
         self._type = type
         self._stages = stages
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, q, type, stages, mul, add, lmax = convertArgsToLists(self._in_fader, freq, q, type, stages, mul, add)
         self._base_objs = [Biquadx_base(wrap(in_fader,i), wrap(freq,i), wrap(q,i), wrap(type,i), wrap(stages,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'q', 'type', 'stages', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -438,7 +428,7 @@ class Biquada(PyoObject):
 
     """
     def __init__(self, input, b0=0.005066, b1=0.010132, b2=0.005066, a0=1.070997, a1=-1.979735, a2=0.929003, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._b0 = Sig(b0)
         self._b1 = Sig(b1)
@@ -446,15 +436,10 @@ class Biquada(PyoObject):
         self._a0 = Sig(a0)
         self._a1 = Sig(a1)
         self._a2 = Sig(a2)
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, b0, b1, b2, a0, a1, a2, mul, add, lmax = convertArgsToLists(self._in_fader, self._b0, self._b1, self._b2, self._a0, self._a1, self._a2, mul, add)
         self._base_objs = [Biquada_base(wrap(in_fader,i), wrap(b0,i), wrap(b1,i), wrap(b2,i), wrap(a0,i), wrap(a1,i), wrap(a2,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'b0', 'b1', 'b2', 'a0', 'a1', 'a2', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -679,21 +664,16 @@ class EQ(PyoObject):
 
     """
     def __init__(self, input, freq=1000, q=1, boost=-3.0, type=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._q = q
         self._boost = boost
         self._type = type
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, q, boost, type, mul, add, lmax = convertArgsToLists(self._in_fader, freq, q, boost, type, mul, add)
         self._base_objs = [EQ_base(wrap(in_fader,i), wrap(freq,i), wrap(q,i), wrap(boost,i), wrap(type,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'q', 'boost', 'type', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -840,18 +820,100 @@ class Tone(PyoObject):
 
     """
     def __init__(self, input, freq=1000, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, mul, add, lmax = convertArgsToLists(self._in_fader, freq, mul, add)
         self._base_objs = [Tone_base(wrap(in_fader,i), wrap(freq,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'mul', 'add']
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
         
+        Parameters:
+
+        x : PyoObject
+            New signal to process.
+        fadetime : float, optional
+            Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+        
+    def setFreq(self, x):
+        """
+        Replace the `freq` attribute.
+        
+        Parameters:
+
+        x : float or PyoObject
+            New `freq` attribute.
+
+        """
+        self._freq = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setFreq(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMapFreq(self._freq), SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+      
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def freq(self):
+        """float or PyoObject. Cutoff frequency of the filter.""" 
+        return self._freq
+    @freq.setter
+    def freq(self, x): self.setFreq(x)
+
+class Atone(PyoObject):
+    """
+    A first-order recursive high-pass filter with variable frequency response.
+ 
+    Parentclass: PyoObject
+   
+    Parameters:
+    
+    input : PyoObject
+        Input signal to process.
+    freq : float or PyoObject, optional
+        Cutoff frequency of the filter in hertz. Default to 1000.
+
+    Methods:
+
+    setInput(x, fadetime) : Replace the `input` attribute.
+    setFreq(x) : Replace the `freq` attribute.
+
+    Attributes:
+
+    input : PyoObject. Input signal to process.
+    freq : float or PyoObject. Cutoff frequency of the filter.
+    
+    Examples:
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> n = Noise(.3)
+    >>> lf = Sine(freq=.2, mul=5000, add=6000)
+    >>> f = Atone(n, lf).mix(2).out()
+
+    """
+    def __init__(self, input, freq=1000, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._freq = freq
+        self._in_fader = InputFader(input)
+        in_fader, freq, mul, add, lmax = convertArgsToLists(self._in_fader, freq, mul, add)
+        self._base_objs = [Atone_base(wrap(in_fader,i), wrap(freq,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -946,19 +1008,14 @@ class Port(PyoObject):
     
     """
     def __init__(self, input, risetime=0.05, falltime=0.05, init=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._risetime = risetime
         self._falltime = falltime
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, risetime, falltime, init, mul, add, lmax = convertArgsToLists(self._in_fader, risetime, falltime, init, mul, add)
         self._base_objs = [Port_base(wrap(in_fader,i), wrap(risetime,i), wrap(falltime,i), wrap(init,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'risetime', 'falltime', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -1057,17 +1114,12 @@ class DCBlock(PyoObject):
 
     """
     def __init__(self, input, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, mul, add, lmax = convertArgsToLists(self._in_fader, mul, add)
         self._base_objs = [DCBlock_base(wrap(in_fader,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'mul', 'add']
-        
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -1083,10 +1135,6 @@ class DCBlock(PyoObject):
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-      
     @property
     def input(self):
         """PyoObject. Input signal to process.""" 
@@ -1142,14 +1190,12 @@ class BandSplit(PyoObject):
 
     """
     def __init__(self, input, num=6, min=20, max=20000, q=1, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._num = num
         self._min = min
         self._max = max
         self._q = q
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, q, lmax = convertArgsToLists(self._in_fader, q)
         self._op_duplicate = lmax
@@ -1160,9 +1206,6 @@ class BandSplit(PyoObject):
             for i in range(lmax):
                 self._base_objs.append(BandSplit_base(wrap(self._base_players,i), j, wrap(mul,j), wrap(add,j)))
 
-    def __dir__(self):
-        return ['input', 'q', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -1262,13 +1305,11 @@ class FourBand(PyoObject):
 
     """
     def __init__(self, input, freq1=150, freq2=500, freq3=2000, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq1 = freq1
         self._freq2 = freq2
         self._freq3 = freq3
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq1, freq2, freq3, lmax = convertArgsToLists(self._in_fader, freq1, freq2, freq3)
         self._op_duplicate = lmax
@@ -1279,9 +1320,6 @@ class FourBand(PyoObject):
             for i in range(lmax):
                 self._base_objs.append(FourBand_base(wrap(self._base_players,i), j, wrap(mul,j), wrap(add,j)))
 
-    def __dir__(self):
-        return ['input', 'freq1', 'freq2', 'freq3', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -1431,12 +1469,10 @@ class Hilbert(PyoObject):
 
     """
     def __init__(self, input, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._real_dummy = []
         self._imag_dummy = []
         self._input = input
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, lmax = convertArgsToLists(self._in_fader)
         mul, add, lmax2 = convertArgsToLists(mul, add)
@@ -1447,9 +1483,6 @@ class Hilbert(PyoObject):
                 self._base_objs.append(Hilbert_base(wrap(self._base_players,j), 0, wrap(mul,i), wrap(add,i)))
                 self._base_objs.append(Hilbert_base(wrap(self._base_players,j), 1, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'mul', 'add']
-
     def __getitem__(self, str):
         if str == 'real':
             self._real_dummy.append(Dummy([obj for i, obj in enumerate(self._base_objs) if (i%2) == 0]))
@@ -1499,10 +1532,6 @@ class Hilbert(PyoObject):
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Input signal to process.""" 
@@ -1563,20 +1592,15 @@ class Allpass(PyoObject):
     
     """
     def __init__(self, input, delay=0.01, feedback=0, maxdelay=1, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._delay = delay
         self._feedback = feedback
         self._maxdelay = maxdelay
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, delay, feedback, maxdelay, mul, add, lmax = convertArgsToLists(self._in_fader, delay, feedback, maxdelay, mul, add)
         self._base_objs = [Allpass_base(wrap(in_fader,i), wrap(delay,i), wrap(feedback,i), wrap(maxdelay,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'delay', 'feedback', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -1693,19 +1717,14 @@ class Allpass2(PyoObject):
 
     """
     def __init__(self, input, freq=1000, bw=100, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._bw = bw
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, bw, mul, add, lmax = convertArgsToLists(self._in_fader, freq, bw, mul, add)
         self._base_objs = [Allpass2_base(wrap(in_fader,i), wrap(freq,i), wrap(bw,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'bw', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -1829,22 +1848,17 @@ class Phaser(PyoObject):
 
     """
     def __init__(self, input, freq=1000, spread=1.1, q=10, feedback=0, num=8, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._spread = spread
         self._q = q
         self._feedback = feedback
         self._num= num
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, spread, q, feedback, num, mul, add, lmax = convertArgsToLists(self._in_fader, freq, spread, q, feedback, num, mul, add)
         self._base_objs = [Phaser_base(wrap(in_fader,i), wrap(freq,i), wrap(spread,i), wrap(q,i), wrap(feedback,i), wrap(num,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'spread', 'q', 'feedback', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -2035,7 +2049,7 @@ class Vocoder(PyoObject):
 
     """
     def __init__(self, input, input2, freq=60, spread=1.25, q=20, slope=0.5, stages=24, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._input2 = input2
         self._freq = freq
@@ -2043,16 +2057,11 @@ class Vocoder(PyoObject):
         self._q = q
         self._slope = slope
         self._stages = stages
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         self._in_fader2 = InputFader(input2)
         in_fader, in_fader2, freq, spread, q, slope, stages, mul, add, lmax = convertArgsToLists(self._in_fader, self._in_fader2, freq, spread, q, slope, stages, mul, add)
         self._base_objs = [Vocoder_base(wrap(in_fader,i), wrap(in_fader2,i), wrap(freq,i), wrap(spread,i), wrap(q,i), wrap(slope,i), wrap(stages,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'input2', 'freq', 'spread', 'q', 'slope', 'stages', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -2276,7 +2285,7 @@ class IRWinSinc(PyoObject):
 
     """
     def __init__(self, input, freq=1000, bw=500, type=0, order=256, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._bw = bw
@@ -2285,15 +2294,10 @@ class IRWinSinc(PyoObject):
             order += 1
             print "order argument of IRWinSinc must be even, set to %i" % order
         self._order = order
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, bw, type, order, mul, add, lmax = convertArgsToLists(self._in_fader, freq, bw, type, order, mul, add)                     
         self._base_objs = [IRWinSinc_base(wrap(in_fader,i), wrap(freq,i), wrap(bw,i), wrap(type,i), wrap(order,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'bw', 'type', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -2432,21 +2436,16 @@ class IRAverage(PyoObject):
 
     """
     def __init__(self, input, order=256, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         if (order % 2) != 0:
             order += 1
             print "order argument of IRAverage must be even, set to %i" % order
         self._order = order
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, order, mul, add, lmax = convertArgsToLists(self._in_fader, order, mul, add)                     
         self._base_objs = [IRAverage_base(wrap(in_fader,i), wrap(order,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -2462,10 +2461,6 @@ class IRAverage(PyoObject):
         self._input = x
         self._in_fader.setInput(x, fadetime)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Input signal to process.""" 
@@ -2538,7 +2533,7 @@ class IRPulse(PyoObject):
 
     """
     def __init__(self, input, freq=500, bw=2500, type=0, order=256, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._freq = freq
         self._bw = bw
@@ -2547,15 +2542,10 @@ class IRPulse(PyoObject):
             order += 1
             print "order argument of IRPulse must be even, set to %i" % order
         self._order = order
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, freq, bw, type, order, mul, add, lmax = convertArgsToLists(self._in_fader, freq, bw, type, order, mul, add)                     
         self._base_objs = [IRPulse_base(wrap(in_fader,i), wrap(freq,i), wrap(bw,i), wrap(type,i), wrap(order,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'freq', 'bw', 'type', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -2712,7 +2702,7 @@ class IRFM(PyoObject):
 
     """
     def __init__(self, input, carrier=1000, ratio=0.5, index=3, order=256, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._carrier = carrier
         self._ratio = ratio
@@ -2721,15 +2711,10 @@ class IRFM(PyoObject):
             order += 1
             print "order argument of IRFM must be even, set to %i" % order
         self._order = order
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, carrier, ratio, index, order, mul, add, lmax = convertArgsToLists(self._in_fader, carrier, ratio, index, order, mul, add)                     
         self._base_objs = [IRFM_base(wrap(in_fader,i), wrap(carrier,i), wrap(ratio,i), wrap(index,i), wrap(order,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'carrier', 'ratio', 'index', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -2821,3 +2806,250 @@ class IRFM(PyoObject):
     @index.setter
     def index(self, x): self.setIndex(x)
 
+class SVF(PyoObject):
+    """
+    Fourth-order state variable filter allowing continuous change of the filter type. 
+    
+    Parentclass : PyoObject
+    
+    Parameters:
+    
+    input : PyoObject
+        Input signal to process.
+    freq : float or PyoObject, optional
+        Cutoff or center frequency of the filter. Because this filter becomes
+        unstable at higher frequencies, the `freq` parameter is limited to
+        one-sixth of the sampling rate (7350 Hz at sr=44100). Defaults to 1000.
+    q : float or PyoObject, optional
+        Q of the filter, defined (for bandpass filters) as freq/bandwidth. 
+        Should be between 0.5 and 50. Defaults to 1.
+    type : float or PyoObject, optional
+        This value, in the range 0 to 1, controls the filter type crossfade 
+        on the continuum lowpass-bandpass-highpass.
+            0.0 = lowpass (default)
+            0.5 = bandpass
+            1.0 = highpass
+
+    Methods:
+
+    setInput(x, fadetime) : Replace the `input` attribute.
+    setFreq(x) : Replace the `freq` attribute.
+    setQ(x) : Replace the `q` attribute.
+    setType(x) : Replace the `type` attribute.
+    
+    Attributes:
+    
+    input : PyoObject. Input signal to process.
+    freq : float or PyoObject. Cutoff or center frequency of the filter.
+    q : float or PyoObject. Q of the filter.
+    type : float or PyoObject. Crossfade between filter types.
+    
+    Examples:
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> a = Noise(.2)
+    >>> lf1 = Sine([.22,.25]).range(500, 2000)
+    >>> lf2 = Sine([.17,.15]).range(1, 4)
+    >>> lf3 = Sine([.23,.2]).range(0, 1)
+    >>> b = SVF(a, freq=lf1, q=lf2, type=lf3).out()
+
+    """
+    def __init__(self, input, freq=1000, q=1, type=0, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._freq = freq
+        self._q = q
+        self._type = type
+        self._in_fader = InputFader(input)
+        in_fader, freq, q, type, mul, add, lmax = convertArgsToLists(self._in_fader, freq, q, type, mul, add)
+        self._base_objs = [SVF_base(wrap(in_fader,i), wrap(freq,i), wrap(q,i), wrap(type,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        Parameters:
+
+        x : PyoObject
+            New signal to process.
+        fadetime : float, optional
+            Crossfade time between old and new input. Defaults to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+        
+    def setFreq(self, x):
+        """
+        Replace the `freq` attribute. Limited in the upper bound to
+        one-sixth of the sampling rate.
+        
+        Parameters:
+
+        x : float or PyoObject
+            New `freq` attribute.
+
+        """
+        self._freq = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setFreq(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setQ(self, x):
+        """
+        Replace the `q` attribute. Should be between 0.5 and 50.
+        
+        Parameters:
+
+        x : float or PyoObject
+            New `q` attribute.
+
+        """
+        self._q = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setQ(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setType(self, x):
+        """
+        Replace the `type` attribute. Must be in the range 0 to 1.
+        
+        This value allows the filter type to sweep from a lowpass (0) 
+        to a bandpass (0.5) and then, from the bandpass to a highpass (1). 
+        
+        Parameters:
+
+        x : float or PyoObject
+            New `type` attribute. 
+
+        """
+        self._type = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setType(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMap(20, 7350, "log", "freq", self._freq), 
+                          SLMap(0.5, 10, "log", "q", self._q),
+                          SLMap(0, 1, "lin", "type", self._type),
+                          SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def freq(self):
+        """float or PyoObject. Cutoff or center frequency of the filter.""" 
+        return self._freq
+    @freq.setter
+    def freq(self, x): self.setFreq(x)
+
+    @property
+    def q(self):
+        """float or PyoObject. Q of the filter.""" 
+        return self._q
+    @q.setter
+    def q(self, x): self.setQ(x)
+
+    @property
+    def type(self):
+        """float or PyoObject. Crossfade between filter types.""" 
+        return self._type
+    @type.setter
+    def type(self, x): self.setType(x)
+
+class Average(PyoObject):
+    """
+    Moving average filter.
+    
+    As the name implies, the moving average filter operates by averaging a number
+    of points from the input signal to produce each point in the output signal.
+    In spite of its simplicity, the moving average filter is optimal for
+    a common task: reducing random noise while retaining a sharp step response.
+
+    Parentclass: PyoObject
+   
+    Parameters:
+    
+    input : PyoObject
+        Input signal to process.
+    size : int, optional
+        Filter kernel size, which is the number of samples used in the 
+        moving average. Default to 10.
+
+    Methods:
+
+    setInput(x, fadetime) : Replace the `input` attribute.
+    setSize(x) : Replace the `size` attribute.
+
+    Attributes:
+
+    input : PyoObject. Input signal to process.
+    size : int. Filter kernel size in samples.
+    
+    Examples:
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> a = Noise(.025)
+    >>> b = Sine(250, mul=0.3)
+    >>> c = Average(a+b, size=100).out()
+
+    """
+    def __init__(self, input, size=10, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._size = size
+        self._in_fader = InputFader(input)
+        in_fader, size, mul, add, lmax = convertArgsToLists(self._in_fader, size, mul, add)
+        self._base_objs = [Average_base(wrap(in_fader,i), wrap(size,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        Parameters:
+
+        x : PyoObject
+            New signal to process.
+        fadetime : float, optional
+            Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+        
+    def setSize(self, x):
+        """
+        Replace the `size` attribute.
+        
+        Parameters:
+
+        x : int
+            New `size` attribute.
+
+        """
+        self._size = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setSize(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+      
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def size(self):
+        """int. Filter kernel size in samples.""" 
+        return self._size
+    @size.setter
+    def size(self, x): self.setSize(x)
