@@ -30,6 +30,8 @@ along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
 from _core import *
 from _maps import *
+from _widgets import createSpectrumWindow
+from pattern import Pattern
 
 class FFT(PyoObject):
     """
@@ -115,8 +117,6 @@ class FFT(PyoObject):
     """
     def __init__(self, input, size=1024, overlaps=4, wintype=2):
         PyoObject.__init__(self)
-        mul = 1
-        add = 0
         self._real_dummy = []
         self._imag_dummy = []
         self._bin_dummy = []
@@ -124,8 +124,6 @@ class FFT(PyoObject):
         self._size = size
         self._overlaps = overlaps
         self._wintype = wintype
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, size, wintype, lmax = convertArgsToLists(self._in_fader, size, wintype)
         self._base_players = []
@@ -137,13 +135,10 @@ class FFT(PyoObject):
         self._imag_objs = []
         self._bin_objs = []
         for j in range(len(self._base_players)):
-            self._real_objs.append(FFT_base(wrap(self._base_players,j), 0, mul, add))
-            self._imag_objs.append(FFT_base(wrap(self._base_players,j), 1, mul, add))
-            self._bin_objs.append(FFT_base(wrap(self._base_players,j), 2, mul, add))
+            self._real_objs.append(FFT_base(wrap(self._base_players,j), 0, self._mul, self._add))
+            self._imag_objs.append(FFT_base(wrap(self._base_players,j), 1, self._mul, self._add))
+            self._bin_objs.append(FFT_base(wrap(self._base_players,j), 2, self._mul, self._add))
             
-    def __dir__(self):
-        return ['input', 'size', 'wintype', 'mul', 'add']
-
     def __len__(self):
         return len(self._real_objs)
 
@@ -249,10 +244,6 @@ class FFT(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setWinType(wrap(x,i)) for i, obj in enumerate(self._base_players)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Input signal to process.""" 
@@ -356,14 +347,12 @@ class IFFT(PyoObject):
 
     """
     def __init__(self, inreal, inimag, size=1024, overlaps=4, wintype=2, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._inreal = inreal
         self._inimag = inimag
         self._size = size
         self._overlaps = overlaps
         self._wintype = wintype
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(inreal)
         self._in_fader2 = InputFader(inimag)
         in_fader, in_fader2, size, wintype, mul, add, lmax = convertArgsToLists(self._in_fader, self._in_fader2, size, wintype, mul, add)
@@ -373,9 +362,6 @@ class IFFT(PyoObject):
             hopsize = wrap(size,i) * ((i/ratio)%overlaps) / overlaps
             self._base_objs.append(IFFT_base(wrap(in_fader,i), wrap(in_fader2,i), wrap(size,i), hopsize, wrap(wintype,i), wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['inreal', 'inimag', 'size', 'wintype', 'mul', 'add']
-
     def __len__(self):
         return len(self._inreal)
         
@@ -533,13 +519,11 @@ class CarToPol(PyoObject):
 
     """
     def __init__(self, inreal, inimag, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._mag_dummy = []
         self._ang_dummy = []
         self._inreal = inreal
         self._inimag = inimag
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(inreal)
         self._in_fader2 = InputFader(inimag)
         in_fader, in_fader2, mul, add, lmax = convertArgsToLists(self._in_fader, self._in_fader2, mul, add)
@@ -548,9 +532,6 @@ class CarToPol(PyoObject):
             self._base_objs.append(CarToPol_base(wrap(in_fader,i), wrap(in_fader2,i), 0, wrap(mul,i), wrap(add,i)))
             self._base_objs.append(CarToPol_base(wrap(in_fader,i), wrap(in_fader2,i), 1, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['inreal', 'inimag', 'mul', 'add']
-
     def __len__(self):
         return len(self._inreal)
 
@@ -618,10 +599,6 @@ class CarToPol(PyoObject):
         self._inimag = x
         self._in_fader2.setInput(x, fadetime)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def inreal(self):
         """PyoObject. Real input signal.""" 
@@ -697,13 +674,11 @@ class PolToCar(PyoObject):
 
     """
     def __init__(self, inmag, inang, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._real_dummy = []
         self._imag_dummy = []
         self._inmag = inmag
         self._inang = inang
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(inmag)
         self._in_fader2 = InputFader(inang)
         in_fader, in_fader2, mul, add, lmax = convertArgsToLists(self._in_fader, self._in_fader2, mul, add)
@@ -712,9 +687,6 @@ class PolToCar(PyoObject):
             self._base_objs.append(PolToCar_base(wrap(in_fader,i), wrap(in_fader2,i), 0, wrap(mul,i), wrap(add,i)))
             self._base_objs.append(PolToCar_base(wrap(in_fader,i), wrap(in_fader2,i), 1, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['inmag', 'inang', 'mul', 'add']
-
     def __len__(self):
         return len(self._inmag)
 
@@ -782,10 +754,6 @@ class PolToCar(PyoObject):
         self._inang = x
         self._in_fader2.setInput(x, fadetime)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def inmag(self):
         """PyoObject. Magnitude input signal.""" 
@@ -866,12 +834,10 @@ class FrameDelta(PyoObject):
 
     """
     def __init__(self, input, framesize=1024, overlaps=4, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._framesize = framesize
         self._overlaps = overlaps
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, framesize, overlaps, mul, add, lmax = convertArgsToLists(self._in_fader, framesize, overlaps, mul, add)
         num_of_mains = len(self._in_fader) / self._overlaps
@@ -888,9 +854,6 @@ class FrameDelta(PyoObject):
             overlap = i / num_of_mains
             self._base_objs.append(FrameDelta_base(self._base_players[base_player], overlap, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'framesize', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -923,10 +886,6 @@ class FrameDelta(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setFrameSize(wrap(x,i)) for i, obj in enumerate(self._base_players)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Phase input signal.""" 
@@ -1007,12 +966,10 @@ class FrameAccum(PyoObject):
 
     """
     def __init__(self, input, framesize=1024, overlaps=4, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._framesize = framesize
         self._overlaps = overlaps
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, framesize, overlaps, mul, add, lmax = convertArgsToLists(self._in_fader, framesize, overlaps, mul, add)
         num_of_mains = len(self._in_fader) / self._overlaps
@@ -1029,9 +986,6 @@ class FrameAccum(PyoObject):
             overlap = i / num_of_mains
             self._base_objs.append(FrameAccum_base(self._base_players[base_player], overlap, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'framesize', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -1064,10 +1018,6 @@ class FrameAccum(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setFrameSize(wrap(x,i)) for i, obj in enumerate(self._base_players)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Phase input signal.""" 
@@ -1149,15 +1099,13 @@ class Vectral(PyoObject):
 
     """
     def __init__(self, input, framesize=1024, overlaps=4, up=1.0, down=0.7, damp=0.9, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._framesize = framesize
         self._overlaps = overlaps
         self._up = up
         self._down = down
         self._damp = damp
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, framesize, overlaps, up, down, damp, mul, add, lmax = convertArgsToLists(self._in_fader, framesize, overlaps, up, down, damp, mul, add)
         num_of_mains = len(self._in_fader) / self._overlaps
@@ -1174,9 +1122,6 @@ class Vectral(PyoObject):
             overlap = i / num_of_mains
             self._base_objs.append(Vectral_base(self._base_players[base_player], overlap, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'framesize', 'up', 'down', 'damp', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -1292,3 +1237,556 @@ class Vectral(PyoObject):
         return self._damp
     @damp.setter
     def damp(self, x): self.setDamp(x)
+    
+class CvlVerb(PyoObject):
+    """
+    Convolution based reverb.
+
+    CvlVerb implements convolution based on a uniformly partitioned overlap-save 
+    algorithm. This object can be used to convolve an input signal with an 
+    impulse response soundfile to simulate real acoustic spaces.
+    
+    Parentclass : PyoObject
+    
+    Parameters:
+    
+    input : PyoObject
+        Input signal to process.
+    impulse : string, optional
+        Path to the impulse response soundfile. The file must have the same 
+        sampling rate as the server to get the proper convolution. Available at
+        initialization time only. Defaults to 'IRMediumHallStereo.wav', located 
+        in pyolib SNDS_PATH folder.
+    size : int {pow-of-two}, optional
+        The size in samples of each partition of the impulse file. Small size means
+        smaller latency but more computation time. If not a power-of-2, the object
+        will find the next power-of-2 greater and use that as the actual partition size.
+        This value must also be greater or equal than the server's buffer size.
+        Available at initialization time only. Defaults to 1024.
+    bal : float or PyoObject, optional
+        Balance between wet and dry signal, between 0 and 1. 0 means no 
+        reverb. Defaults to 0.25.
+
+    Methods:
+    
+    setInput(x, fadetime) : Replace the `input` attribute.
+    setBal(x) : Replace the `bal` attribute.
+
+    Attributes:
+    
+    input : PyoObject. Input signal to process.
+    bal : float or PyoObject. Balance between wet and dry signal.
+        
+    Examples:
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> sf = SfPlayer(SNDS_PATH+"/transparent.aif", loop=True, mul=0.5)
+    >>> cv = CvlVerb(sf, SNDS_PATH+"/IRMediumHallStereo.wav", size=1024, bal=0.4).out()
+
+    """
+    def __init__(self, input, impulse=SNDS_PATH+"/IRMediumHallStereo.wav", bal=0.25, size=1024, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._impulse = impulse
+        self._bal = bal
+        self._size = size
+        self._in_fader = InputFader(input)
+        in_fader, bal, size, mul, add, lmax = convertArgsToLists(self._in_fader, bal, size, mul, add)
+        impulse, lmax2 = convertArgsToLists(impulse)
+        self._base_objs = []
+        for file in impulse:
+            _size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(file)
+            lmax3 = max(lmax, _snd_chnls)
+            self._base_objs.extend([CvlVerb_base(wrap(in_fader,i), file, wrap(bal,i), wrap(size,i), i%_snd_chnls, wrap(mul,i), wrap(add,i)) for i in range(lmax3)])
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        Parameters:
+
+        x : PyoObject
+            New signal to process.
+        fadetime : float, optional
+            Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+
+    def setBal(self, x):
+        """
+        Replace the `bal` attribute.
+
+        Parameters:
+
+        x : float or PyoObject
+            new `bal` attribute.
+
+        """
+        self._bal = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setBal(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMap(0., 1., "lin", "bal", self._bal),
+                          SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def bal(self):
+        """float or PyoObject. Wet / dry balance.""" 
+        return self._bal
+    @bal.setter
+    def bal(self, x): self.setBal(x)
+
+class Spectrum(PyoObject):
+    """
+    Spectrum analyzer and display.
+
+    Spectrum measures the magnitude of an input signal versus frequency
+    within a user defined range. It can show both magnitude and frequency
+    on linear or logarithmic scale.
+    
+    Parentclass : PyoObject
+    
+    Parameters:
+    
+    input : PyoObject
+        Input signal to process.
+    size : int {pow-of-two > 4}, optional
+        FFT size. Must be a power of two greater than 4.
+        The FFT size is the number of samples used in each
+        analysis frame. Defaults to 1024.
+    wintype : int, optional
+        Shape of the envelope used to filter each input frame.
+        Possible shapes are :
+            0 : rectangular (no windowing)
+            1 : Hamming
+            2 : Hanning
+            3 : Bartlett (triangular)
+            4 : Blackman 3-term
+            5 : Blackman-Harris 4-term
+            6 : Blackman-Harris 7-term
+            7 : Tuckey (alpha = 0.66)
+            8 : Sine (half-sine window)
+    function : python callable, optional
+        If set, this function will be called with magnitudes (as
+        list of lists, one list per channel). Useful if someone
+        wants to save the analysis data into a text file.
+        Defaults to None.
+
+    Methods:
+    
+    setInput(x, fadetime) : Replace the `input` attribute.
+    setSize(x) : Replace the `size` attribute.
+    setWinType(x) : Replace the `wintype` attribute. 
+    setFunction(callable) : Sets the function to be called to retrieve the analysis data.
+    poll(boolean) : Turns on and off the analysis polling. (defaults to True).
+    polltime(time) : Sets the polling time in seconds (defaults to 0.05).
+    setLowbound(x) : Sets the lower frequency, as multiplier of sr, returned by the analysis.
+    setHighbound(x) : Sets the higher frequency, as multiplier of sr, returned by the analysis.
+    getLowfreq() : Returns the current lower frequency, in Hz, used by the analysis.
+    getHighfreq() : Returns the current higher frequency, in Hz, used by the analysis.
+    setWidth(x) : Sets the width of the current display.
+    setHeight(x) : Sets the height of the current display.
+    setFscaling(boolean) : Sets the frequency display to linear or logarithmic.
+    setMscaling(boolean) : Sets the magnitude display to linear or logarithmic.
+    getFscaling() : Returns the scaling of the frequency display (lin or log).
+    getMscaling() : Returns the scaling of the magnitude display (lin or log).
+    setGain(x) : Set the gain of the anaysis data. For drawing purpose.
+    view(title, wxnoserver) : Opens a window showing the result of the analysis.
+    refreshView() : Updates the graphical display of the spectrum.
+
+    Attributes:
+    
+    input : PyoObject. Input signal to process.
+    size : int {pow-of-two > 4}. FFT size.
+    wintype : int. Shape of the envelope.
+    gain : float. Gain of the analysis data.
+    lowbound : float. Lowest frequency (multiplier of sr) to output.
+    highbound : float. Highest frequency (multiplier of sr) to output.
+    width : int. Width, in pixels, of the current display.
+    height : int. Height, in pixels, of the current display.
+    fscaling : boolean. Scaling of the frequency display.
+    mscaling : boolean. Scaling of the magnitude display.
+
+    Notes:
+    
+    Spectrum has no `out` method.
+    Spectrum has no `mul` and `add` attributes.
+
+    Examples:
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> a = SuperSaw(freq=[500,750], detune=0.6, bal=0.7, mul=0.5).out()
+    >>> spec = Spectrum(a, size=1024)
+
+    """
+    def __init__(self, input, size=1024, wintype=2, function=None):
+        PyoObject.__init__(self)
+        self.points = None
+        self.viewFrame = None
+        self._input = input
+        self._size = size
+        self._wintype = wintype
+        self._function = function
+        self._fscaling = 0
+        self._mscaling = 1
+        self._lowbound = 0
+        self._highbound = 0.5
+        self._width = 500
+        self._height = 400
+        self._gain = 1
+        self._in_fader = InputFader(input)
+        in_fader, size, wintype, lmax = convertArgsToLists(self._in_fader, size, wintype)
+        self._base_objs = [Spectrum_base(wrap(in_fader,i), wrap(size,i), wrap(wintype,i)) for i in range(lmax)]
+        if function == None:
+            self.view()
+        self._timer = Pattern(self.refreshView, 0.05).play()
+ 
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        Parameters:
+
+        x : PyoObject
+            New signal to process.
+        fadetime : float, optional
+            Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+
+    def setSize(self, x):
+        """
+        Replace the `size` attribute.
+        
+        Parameters:
+
+        x : int
+            new `size` attribute.
+        
+        """
+        self._size = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setSize(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setWinType(self, x):
+        """
+        Replace the `wintype` attribute.
+        
+        Parameters:
+
+        x : int
+            new `wintype` attribute.
+        
+        """
+        self._wintype = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setWinType(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setFunction(self, function):
+        """
+        Sets the function to be called to retrieve the analysis data.
+        
+        parameters:
+            
+        function : python callable
+            The function called by the internal timer to retrieve the
+            analysis data. The function must be created with one argument
+            and will receive the data as a list of lists (one list per channel).
+
+        """
+        self._function = function
+
+    def poll(self, active):
+        """
+        Turns on and off the analysis polling.
+        
+        Parameters:
+            
+        active : boolean
+            If True, starts the analysis polling, False to stop it.
+            defaults to True.
+
+        """
+        if active:
+            self._timer.play()
+        else:
+            self._timer.stop()
+
+    def polltime(self, time):
+        """
+        Sets the polling time in seconds.
+        
+        Parameters:
+            
+        time : float
+            Adjusts the frequency of the internal timer used to
+            retrieve the current analysis frame. defaults to 0.05.
+        
+        """
+        self._timer.time = time
+
+    def setLowbound(self, x):
+        """
+        Sets the lower frequency, as multiplier of sr, returned by the analysis.
+        
+        Returns the real low frequency en Hz.
+        
+        Parameters:
+
+        x : float {0 <= x <= 0.5}
+            new `lowbound` attribute.
+        
+        """
+        self._lowbound = x
+        x, lmax = convertArgsToLists(x)
+        tmp = [obj.setLowbound(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+        return tmp[0]
+
+    def setHighbound(self, x):
+        """
+        Sets the higher frequency, as multiplier of sr, returned by the analysis.
+        
+        Returns the real high frequency en Hz.
+        
+        Parameters:
+
+        x : float {0 <= x <= 0.5}
+            new `highbound` attribute.
+        
+        """
+        self._highbound = x
+        x, lmax = convertArgsToLists(x)
+        tmp = [obj.setHighbound(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+        return tmp[0]
+
+    def getLowfreq(self):
+        """
+        Returns the current lower frequency, in Hz, used by the analysis.
+        
+        """
+
+        return self._base_objs[0].getLowfreq()
+
+    def getHighfreq(self):
+        """
+        Returns the current higher frequency, in Hz, used by the analysis.
+        
+        """
+        return self._base_objs[0].getHighfreq()
+
+    def setWidth(self, x):
+        """
+        Sets the width, in pixels, of the current display.
+        
+        Used internally to build the list of points to draw.
+        
+        Parameters:
+
+        x : int
+            new `width` attribute.
+        
+        """
+        self._width = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setWidth(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setHeight(self, x):
+        """
+        Sets the height, in pixels, of the current display.
+        
+        Used internally to build the list of points to draw.
+        
+        Parameters:
+
+        x : int
+            new `height` attribute.
+        
+        """
+        self._height = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setHeight(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setFscaling(self, x):
+        """
+        Sets the frequency display to linear or logarithmic.
+        
+        Parameters:
+
+        x : boolean
+            If True, the frequency display is logarithmic. False turns
+            it back to linear. Defaults to False.
+        
+        """
+        self._fscaling = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setFscaling(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+        if self.viewFrame != None:
+            self.viewFrame.setFscaling(self._fscaling)
+
+    def setMscaling(self, x):
+        """
+        Sets the magnitude display to linear or logarithmic.
+        
+        Parameters:
+
+        x : boolean
+            If True, the magnitude display is logarithmic (which means in dB). 
+            False turns it back to linear. Defaults to True.
+        
+        """
+        self._mscaling = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setMscaling(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+        if self.viewFrame != None:
+            self.viewFrame.setMscaling(self._mscaling)
+
+    def getFscaling(self):
+        """
+        Returns the scaling of the frequency display.
+        
+        Returns True for logarithmic or False for linear.
+
+        """
+        return self._fscaling
+
+    def getMscaling(self):
+        """
+        Returns the scaling of the magnitude display.
+        
+        Returns True for logarithmic or False for linear.
+
+        """
+        return self._mscaling
+
+    def setGain(self, x):
+        """
+        Set the gain of the anaysis data. For drawing purpose.
+        
+        Parameters:
+
+        x : float
+            new `gain` attribute, as linear values.
+        
+        """
+        self._gain = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setGain(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def view(self, title="Spectrum", wxnoserver=False):
+        """
+        Opens a window showing the result of the analysis.
+        
+        Parameters:
+        
+        title : string, optional
+            Window title. Defaults to "Spectrum". 
+        wxnoserver : boolean, optional
+            With wxPython graphical toolkit, if True, tells the 
+            interpreter that there will be no server window and not 
+            to wait for it before showing the table window. 
+            Defaults to False.
+        
+        """
+        createSpectrumWindow(self, title, wxnoserver)
+
+    def _setViewFrame(self, frame):
+        self.viewFrame = frame
+        
+    def refreshView(self):
+        """
+        Updates the graphical display of the spectrum.
+        
+        Called automatically by the internal timer.
+
+        """
+        self.points = [obj.display() for obj in self._base_objs]
+        if self._function != None:
+            self._function(self.points)
+        if self.viewFrame != None:
+            self.viewFrame.update(self.points)
+
+
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def size(self):
+        """int. FFT size."""
+        return self._size
+    @size.setter
+    def size(self, x): self.setSize(x)
+
+    @property
+    def wintype(self):
+        """int. Windowing method."""
+        return self._wintype
+    @wintype.setter
+    def wintype(self, x): self.setWinType(x)
+
+    @property
+    def gain(self):
+        """float. Sets the gain of the analysis data."""
+        return self._gain
+    @gain.setter
+    def gain(self, x): self.setGain(x)
+
+    @property
+    def lowbound(self):
+        """float. Lowest frequency (multiplier of sr) to output."""
+        return self._lowbound
+    @lowbound.setter
+    def lowbound(self, x): self.setLowbound(x)
+
+    @property
+    def highbound(self):
+        """float. Highest frequency (multiplier of sr) to output."""
+        return self._highbound
+    @highbound.setter
+    def highbound(self, x): self.setHighbound(x)
+
+    @property
+    def width(self):
+        """int. Width, in pixels, of the current display."""
+        return self._width
+    @width.setter
+    def width(self, x): self.setWidth(x)
+
+    @property
+    def height(self):
+        """int. Height, in pixels, of the current display."""
+        return self._height
+    @height.setter
+    def height(self, x): self.setHeight(x)
+
+    @property
+    def fscaling(self):
+        """boolean. Scaling of the frequency display."""
+        return self._fscaling
+    @fscaling.setter
+    def fscaling(self, x): self.setFscaling(x)
+
+    @property
+    def mscaling(self):
+        """boolean. Scaling of the magnitude display."""
+        return self._mscaling
+    @mscaling.setter
+    def mscaling(self, x): self.setMscaling(x)
