@@ -89,19 +89,14 @@ class Midictl(PyoObject):
         
     """
     def __init__(self, ctlnumber, minscale=0, maxscale=1, init=0, channel=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._ctlnumber = ctlnumber
         self._minscale = minscale
         self._maxscale = maxscale
         self._channel = channel
-        self._mul = mul
-        self._add = add
         ctlnumber, minscale, maxscale, init, channel, mul, add, lmax = convertArgsToLists(ctlnumber, minscale, maxscale, init, channel, mul, add)
         self._base_objs = [Midictl_base(wrap(ctlnumber,i), wrap(minscale,i), wrap(maxscale,i), wrap(init,i), wrap(channel,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['ctlnumber', 'minscale', 'maxscale', 'channel', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -187,10 +182,6 @@ class Midictl(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setInterpolation(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def ctlnumber(self): return self._ctlnumber
     @ctlnumber.setter
@@ -267,9 +258,6 @@ class CtlScan(PyoObject):
         self._toprint = toprint
         self._base_objs = [CtlScan_base(self._function, self._toprint)]
 
-    def __dir__(self):
-        return []
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -313,10 +301,6 @@ class CtlScan(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setToprint(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def function(self): return self._function
     @function.setter
@@ -383,9 +367,6 @@ class CtlScan2(PyoObject):
         self._toprint = toprint
         self._base_objs = [CtlScan2_base(self._function, self._toprint)]
 
-    def __dir__(self):
-        return []
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -429,10 +410,6 @@ class CtlScan2(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setToprint(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def function(self): return self._function
     @function.setter
@@ -473,6 +450,7 @@ class Notein(PyoObject):
 
     setChannel(x) : Replace the `channel` attribute.
     setCentralKey(x) : Set the midi key where there is no transposition.
+    setStealing(x) : Activates the stealing mode if True. Defaults to False.
     get(identifier, all) : Return the first sample of the current 
         buffer as a float.
 
@@ -505,7 +483,7 @@ class Notein(PyoObject):
     
     """
     def __init__(self, poly=10, scale=0, first=0, last=127, channel=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._pitch_dummy = []
         self._velocity_dummy = []
         self._poly = poly
@@ -513,8 +491,6 @@ class Notein(PyoObject):
         self._first = first
         self._last = last
         self._channel = channel
-        self._mul = mul
-        self._add = add
         mul, add, lmax = convertArgsToLists(mul, add)
         self._base_handler = MidiNote_base(self._poly, self._scale, self._first, self._last, self._channel)
         self._base_objs = []
@@ -522,9 +498,6 @@ class Notein(PyoObject):
             self._base_objs.append(Notein_base(self._base_handler, i, 0, 1, 0))
             self._base_objs.append(Notein_base(self._base_handler, i, 1, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['channel', 'mul', 'add']
-
     def __getitem__(self, str):
         if str == 'pitch':
             self._pitch_dummy.append(Dummy([self._base_objs[i*2] for i in range(self._poly)]))
@@ -561,6 +534,22 @@ class Notein(PyoObject):
         """
         self._base_handler.setCentralKey(x)
 
+    def setStealing(self, x):
+        """
+        Activates the stealing mode if True. Defaults to False.
+        
+        In stealing mode, a new note will overwrite the oldest one
+        according to the polyphony. In non-stealing mode, if the
+        polyphony is already full, the new notes will be ignored.
+
+        Parameters:
+
+        x : boolean
+            True for stealing mode, False for non-stealing.
+
+        """
+        self._base_handler.setStealing(x)
+
     def get(self, identifier="pitch", all=False):
         """
         Return the first sample of the current buffer as a float.
@@ -598,10 +587,6 @@ class Notein(PyoObject):
         self._base_handler.stop()
         return PyoObject.stop(self)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def channel(self): return self._channel
     @channel.setter
@@ -658,18 +643,13 @@ class Bendin(PyoObject):
 
     """
     def __init__(self, brange=2, scale=0, channel=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._brange = brange
         self._scale = scale
         self._channel = channel
-        self._mul = mul
-        self._add = add
         brange, scale, channel, mul, add, lmax = convertArgsToLists(brange, scale, channel, mul, add)
         self._base_objs = [Bendin_base(wrap(brange,i), wrap(scale,i), wrap(channel,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['brange', 'scale', 'channel', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -715,10 +695,6 @@ class Bendin(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setChannel(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def brange(self): 
         """float. Bipolar range of the pitch bend in semitones."""
@@ -790,18 +766,13 @@ class Touchin(PyoObject):
 
     """
     def __init__(self, minscale=0, maxscale=1, init=0, channel=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._minscale = minscale
         self._maxscale = maxscale
         self._channel = channel
-        self._mul = mul
-        self._add = add
         minscale, maxscale, init, channel, mul, add, lmax = convertArgsToLists(minscale, maxscale, init, channel, mul, add)
         self._base_objs = [Touchin_base(wrap(minscale,i), wrap(maxscale,i), wrap(init,i), wrap(channel,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['minscale', 'maxscale', 'channel', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -847,10 +818,6 @@ class Touchin(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setChannel(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def minscale(self): return self._minscale
     @minscale.setter
@@ -905,16 +872,11 @@ class Programin(PyoObject):
 
     """
     def __init__(self, channel=0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._channel = channel
-        self._mul = mul
-        self._add = add
         channel, mul, add, lmax = convertArgsToLists(channel, mul, add)
         self._base_objs = [Programin_base(wrap(channel,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['channel', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -932,10 +894,6 @@ class Programin(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setChannel(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def channel(self): return self._channel
     @channel.setter
@@ -1012,21 +970,16 @@ class MidiAdsr(PyoObject):
 
     """
     def __init__(self, input, attack=0.01, decay=0.05, sustain=0.7, release=0.1, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._attack = attack
         self._decay = decay
         self._sustain = sustain
         self._release = release
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, attack, decay, sustain, release, mul, add, lmax = convertArgsToLists(self._in_fader, attack, decay, sustain, release, mul, add)
         self._base_objs = [MidiAdsr_base(wrap(in_fader,i), wrap(attack,i), wrap(decay,i), wrap(sustain,i), wrap(release,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'attack', 'decay', 'sustain', 'release', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -1101,10 +1054,6 @@ class MidiAdsr(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setRelease(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def attack(self):
         """float. Duration of the attack phase in seconds.""" 
@@ -1210,22 +1159,17 @@ class MidiDelAdsr(PyoObject):
 
     """
     def __init__(self, input, delay=0, attack=0.01, decay=0.05, sustain=0.7, release=0.1, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._delay = delay
         self._attack = attack
         self._decay = decay
         self._sustain = sustain
         self._release = release
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, delay, attack, decay, sustain, release, mul, add, lmax = convertArgsToLists(self._in_fader, delay, attack, decay, sustain, release, mul, add)
         self._base_objs = [MidiDelAdsr_base(wrap(in_fader,i), wrap(delay,i), wrap(attack,i), wrap(decay,i), wrap(sustain,i), wrap(release,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'delay', 'attack', 'decay', 'sustain', 'release', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -1314,10 +1258,6 @@ class MidiDelAdsr(PyoObject):
         x, lmax = convertArgsToLists(x)
         [obj.setRelease(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def delay(self):
         """float. Duration of the delay phase in seconds.""" 
