@@ -34,7 +34,7 @@ along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 import sys
 from _core import *
 from _maps import *
-from types import IntType
+from types import IntType, ListType
 
 ######################################################################
 ### Open Sound Control
@@ -66,6 +66,8 @@ class OscSend(PyoObject):
     Methods:
 
     setInput(x, fadetime) : Replace the `input` attribute.
+    setBufferRate(x) : Sets how many buffers to wait before sending 
+        a new value.
 
     Notes:
 
@@ -89,9 +91,6 @@ class OscSend(PyoObject):
         in_fader, port, address, host, lmax = convertArgsToLists(self._in_fader, port, address, host)
         self._base_objs = [OscSend_base(wrap(in_fader,i), wrap(port,i), wrap(address,i), wrap(host,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
@@ -116,9 +115,18 @@ class OscSend(PyoObject):
     def setAdd(self, x):
         pass    
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
+    def setBufferRate(self, x):
+        """
+        Sets how many buffers to wait before sending a new value.
+        
+        Parameters:
+
+        x : int
+            Changes the data output frequency in multiples of the buffer size.
+            Should be greater or equal to 1.
+
+        """
+        [obj.setBufferRate(x) for obj in self._base_objs]
 
     @property
     def input(self):
@@ -156,6 +164,7 @@ class OscReceive(PyoObject):
     addAddress(path, mul, add) : Adds new address(es) to the object's handler.
     delAddress(path) : Removes address(es) from the object's handler.
     setInterpolation(x) : Activate/Deactivate interpolation. Activated by default.
+    setValue(path, value) : Sets value for the specified address.
 
     Notes:
 
@@ -177,20 +186,15 @@ class OscReceive(PyoObject):
     """
 
     def __init__(self, port, address, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         if type(port) != IntType:
             print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
             exit()
-        self._mul = mul
-        self._add = add
         address, mul, add, lmax = convertArgsToLists(address, mul, add)
         self._address = address
         self._mainReceiver = OscReceiver_base(port, address)
         self._base_objs = [OscReceive_base(self._mainReceiver, wrap(address,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['mul', 'add']
-            
     def __getitem__(self, i):
         if type(i) == type(''):
             return self._base_objs[self._address.index(i)]
@@ -257,6 +261,26 @@ class OscReceive(PyoObject):
         """
         [obj.setInterpolation(x) for obj in self._base_objs]
 
+    def setValue(self, path, value):
+        """
+        Sets value for a given address.
+        
+        Parameters:
+        
+        path : string
+            Address to which the value should be attributed.
+        value : float
+            Value to attribute to the given address.
+
+        """
+        path, value, lmax = convertArgsToLists(path, value)
+        for i in range(lmax):
+            p = wrap(path,i)
+            if p in self._address:
+                self._mainReceiver.setValue(p, wrap(value,i))
+            else:
+                print 'Error: OscReceive.setValue, Illegal address "%s"' % p 
+
     def get(self, identifier=None, all=False):
         """
         Return the first sample of the current buffer as a float.
@@ -287,10 +311,6 @@ class OscReceive(PyoObject):
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-        
 class OscDataSend(PyoObject):
     """
     Sends data values over a network via the Open Sound Control protocol.
@@ -361,9 +381,6 @@ class OscDataSend(PyoObject):
         for i, adr in enumerate(address):
             self._addresses[adr] = self._base_objs[i]
             
-    def __dir__(self):
-        return []
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -448,10 +465,6 @@ class OscDataSend(PyoObject):
         else:
             self._addresses[address].send(msg)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
 class OscDataReceive(PyoObject):
     """
     Receives data values over a network via the Open Sound Control protocol.
@@ -510,7 +523,7 @@ class OscDataReceive(PyoObject):
 
     """
 
-    def __init__(self, port, address, function, mul=1, add=0):
+    def __init__(self, port, address, function):
         PyoObject.__init__(self)
         if type(port) != IntType:
             print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
@@ -524,8 +537,11 @@ class OscDataReceive(PyoObject):
         # self._address is linked with list at C level
         self._base_objs = [OscDataReceive_base(port, self._address, function)]
 
-    def __dir__(self):
-        return []
+    def setMul(self, x):
+        pass
+        
+    def setAdd(self, x):
+        pass
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
@@ -567,10 +583,6 @@ class OscDataReceive(PyoObject):
             index = self._address.index(p)
             self._base_objs[0].delAddress(index)
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
 class OscListReceive(PyoObject):
     """
     Receives list of values over a network via the Open Sound Control protocol.
@@ -605,6 +617,7 @@ class OscListReceive(PyoObject):
     addAddress(path, mul, add) : Adds new address(es) to the object's handler.
     delAddress(path) : Removes address(es) from the object's handler.
     setInterpolation(x) : Activate/Deactivate interpolation. Activated by default.
+    setValue(path, value) : Sets value for the specified address.
 
     Notes:
 
@@ -627,7 +640,7 @@ class OscListReceive(PyoObject):
     """
 
     def __init__(self, port, address, num=8, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         if type(port) != IntType:
             print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
             exit()
@@ -636,16 +649,11 @@ class OscListReceive(PyoObject):
             exit()
         self._num = num
         self._op_duplicate = self._num
-        self._mul = mul
-        self._add = add
         address, mul, add, lmax = convertArgsToLists(address, mul, add)
         self._address = address
         self._mainReceiver = OscListReceiver_base(port, address, num)
         self._base_objs = [OscListReceive_base(self._mainReceiver, wrap(address,i), j, wrap(mul,i), wrap(add,i)) for i in range(lmax) for j in range(self._num)]
         
-    def __dir__(self):
-        return ['mul', 'add']
-
     def __getitem__(self, i):
         if type(i) == type(''):
             first = self._address.index(i) * self._num
@@ -716,6 +724,33 @@ class OscListReceive(PyoObject):
         """
         [obj.setInterpolation(x) for obj in self._base_objs]
 
+    def setValue(self, path, value):
+        """
+        Sets value for a given address.
+        
+        Parameters:
+        
+        path : string
+            Address to which the value should be attributed.
+        value : list of floats
+            List of values to attribute to the given address.
+
+        """
+        path, lmax = convertArgsToLists(path)
+        for i in range(lmax):
+            p = wrap(path,i)
+            if p in self._address:
+                if type(value[0]) == ListType:
+                    val = wrap(value,i)
+                else:
+                    val = value
+                if len(val) == self._num:
+                    self._mainReceiver.setValue(p, val)
+                else:
+                    print 'Error: OscListReceive.setValue, value must be of the same length as the `num` attribute.'
+            else:
+                print 'Error: OscListReceive.setValue, Illegal address "%s"' % p 
+
     def get(self, identifier=None, all=False):
         """
         Return the first list of samples of the current buffer as floats.
@@ -751,7 +786,3 @@ class OscListReceive(PyoObject):
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
-
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
