@@ -18,6 +18,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
+import os, time
 from _core import *
 from _widgets import createServerGUI
         
@@ -83,9 +84,12 @@ class Server(object):
     getBufferSize() : Returns the current buffer size.
     getGlobalSeed() : Returns the server's global seed.
     getIsStarted() : Returns 1 if the server is started, otherwise returns 0.
+    getIsBooted() : Returns 1 if the server is booted, otherwise returns 0.
     getMidiActive() : Returns 1 if Midi callback is active, otherwise returns 0.
     getStreams() : Returns the list of Stream objects currently in the Server memory.
     getNumberOfStreams() : Returns the number of streams currently in the Server memory.
+    sendMidiNote(pitch, velocity, channel, timestamp) : Send a MIDI note message to the 
+        selected output device.
 
     The next methods must be called before booting the server
 
@@ -93,6 +97,7 @@ class Server(object):
     setInputDevice(x) : Set the audio input device number. See `pa_list_devices()`.
     setOutputDevice(x) : Set the audio output device number. See `pa_list_devices()`.
     setMidiInputDevice(x) : Set the MIDI input device number. See `pm_list_devices()`.
+    setMidiOutputDevice(x) : Set the MIDI output device number. See `pm_list_devices()`.
     setSamplingRate(x) : Set the sampling rate used by the server.
     setBufferSize(x) : Set the buffer size used by the server.
     setNchnls(x) : Set the number of channels used by the server.
@@ -119,6 +124,9 @@ class Server(object):
         
     """
     def __init__(self, sr=44100, nchnls=2, buffersize=256, duplex=1, audio='portaudio', jackname='pyo'):
+        if os.environ.has_key("PYO_SERVER_AUDIO") and "offline" not in audio:
+            audio = os.environ["PYO_SERVER_AUDIO"]
+        self._time = time
         self._nchnls = nchnls
         self._amp = 1.
         self._verbosity = 7
@@ -128,6 +136,15 @@ class Server(object):
         self._fileformat = 0
         self._sampletype = 0
         self._server = Server_base(sr, nchnls, buffersize, duplex, audio, jackname)
+        self._server._setDefaultRecPath(os.path.join(os.path.expanduser("~"), "pyo_rec.wav"))
+
+    def __del__(self):
+        if self.getIsBooted():
+            if self.getIsStarted():
+                self.stop()
+                self._time.sleep(.25)
+            self.shutdown()
+            self._time.sleep(.25)
 
     def reinit(self, sr=44100, nchnls=2, buffersize=256, duplex=1, audio='portaudio', jackname='pyo'):
         """
@@ -229,6 +246,18 @@ class Server(object):
 
         """
         self._server.setMidiInputDevice(x)
+
+    def setMidiOutputDevice(self, x):
+        """
+        Set the Midi output device number. See `pm_list_devices()`.
+        
+        Parameters:
+
+        x : int
+            Number of the Midi device listed by Portmidi.
+
+        """
+        self._server.setMidiOutputDevice(x)
  
     def setSamplingRate(self, x):
         """
@@ -453,7 +482,24 @@ class Server(object):
         
         """
         self._server.recstop()
+
+    def sendMidiNote(self, pitch, velocity, channel=0, timestamp=0):
+        """
+        Send a MIDI note message to the selected output device. 
         
+        Parameters:
+        
+        pitch : int
+            Midi pitch, between 0 and 127.
+        velocity : int
+            Amplitude of the note, between 0 and 127. A note
+            with a velocity of 0 is equivalent to a note off.
+        channel : int, optional
+            The Midi channel, between 1 and 16, on which the 
+            note is sent. A channel of 0 means all channels. 
+        """
+        self._server.sendMidiNote(pitch, velocity, channel, timestamp)
+
     def getStreams(self):
         """
         Return the list of streams loaded in the server.
@@ -496,6 +542,13 @@ class Server(object):
         """
         return self._server.getIsStarted()
 
+    def getIsBooted(self):
+        """
+        Returns 1 if the server is booted, otherwise returns 0.
+        
+        """
+        return self._server.getIsBooted()
+
     def getMidiActive(self):
         """
         Returns 1 if Midi callback is active, otherwise returns 0.
