@@ -29,6 +29,7 @@
 #include "structmember.h"
 #include "portaudio.h"
 #include "portmidi.h"
+#include "porttime.h"
 #include "sndfile.h"
 #include "streammodule.h"
 #include "pyomodule.h"
@@ -280,7 +281,7 @@ jack_srate_cb (jack_nframes_t nframes, void *arg)
 {
     Server *s = (Server *) arg;
     s->samplingRate = (double) nframes;
-    Server_debug(s, "the sample rate is now %lu/sec\n", (unsigned long) nframes);
+    Server_debug(s, "The sample rate is now %lu/sec\n", (unsigned long) nframes);
     return 0;
 }
 
@@ -289,7 +290,7 @@ jack_bufsize_cb (jack_nframes_t nframes, void *arg)
 {
     Server *s = (Server *) arg;
     s->bufferSize = (int) nframes;
-    Server_debug(s, "the buffer size is now %lu/sec\n", (unsigned long) nframes);
+    Server_debug(s, "The buffer size is now %lu/sec\n", (unsigned long) nframes);
     return 0;
 }
 
@@ -421,7 +422,6 @@ Server_pa_init(Server *self)
     PaHostApiTypeId hostId;
     PaSampleFormat sampleFormat;
     PaStreamCallback *streamCallback;
-    double deviceDefaultSamplingRate;
 
     err = Pa_Initialize();
     portaudio_assert(err, "Pa_Initialize");
@@ -445,7 +445,6 @@ Server_pa_init(Server *self)
 
     /* Retrieve host api id and define sample and callback format*/
     deviceInfo = Pa_GetDeviceInfo(outDevice);
-    deviceDefaultSamplingRate = deviceInfo->defaultSampleRate;
     hostIndex = deviceInfo->hostApi;
     hostInfo = Pa_GetHostApiInfo(hostIndex);
     hostId = hostInfo->type;
@@ -516,12 +515,12 @@ Server_pa_deinit(Server *self)
 
     if (Pa_IsStreamActive(be_data->stream) || ! Pa_IsStreamStopped(be_data->stream)) {
         self->server_started = 0;
-        //err = Pa_StopStream(be_data->stream);
-        //portaudio_assert(err, "Pa_StopStream");
+        err = Pa_StopStream(be_data->stream);
+        portaudio_assert(err, "Pa_StopStream");
     }
     
-//    err = Pa_CloseStream(be_data->stream);
-//    portaudio_assert(err, "Pa_CloseStream");
+    err = Pa_CloseStream(be_data->stream);
+    portaudio_assert(err, "Pa_CloseStream");
     
     err = Pa_Terminate();
     portaudio_assert(err, "Pa_Terminate");
@@ -563,7 +562,7 @@ Server_jack_autoconnect (Server *self)
     int ret = 0;
     PyoJackBackendData *be_data = (PyoJackBackendData *) self->audio_be_data;
     if ((ports = jack_get_ports (be_data->jack_client, NULL, NULL, 
-        JackPortIsPhysical|JackPortIsOutput)) == NULL) {
+        JackPortIsOutput)) == NULL) {
         Server_error(self, "Jack: Cannot find any physical capture ports\n");
         ret = -1;
     }
@@ -578,7 +577,7 @@ Server_jack_autoconnect (Server *self)
     free (ports);
     
     if ((ports = jack_get_ports (be_data->jack_client, NULL, NULL, 
-        JackPortIsPhysical|JackPortIsInput)) == NULL) {
+        JackPortIsInput)) == NULL) {
         Server_error(self, "Jack: Cannot find any physical playback ports\n");
         ret = -1;
     }
@@ -1099,6 +1098,7 @@ void
         sf_close(self->recfile);
         Server_message(self,"Offline Server rendering finished.\n");         
     }
+    return NULL;
 }
 
 int
@@ -1334,10 +1334,14 @@ Server_shut_down(Server *self)
         Server_error(self, "Error closing audio backend.\n");
     }
     
-    if (self->withPortMidi == 1) {
+    if (self->withPortMidi == 1)
         Pm_Close(self->in);
+
+    if (self->withPortMidiOut == 1)
+        Pm_Close(self->out);
+    
+    if (self->withPortMidi == 1 || self->withPortMidiOut == 1)
         Pm_Terminate();
-    }
     
     Py_INCREF(Py_None);
     return Py_None;
@@ -1391,6 +1395,7 @@ Server_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->input = -1;
     self->output = -1;
     self->midi_input = -1;
+    self->midi_output = -1;
     self->amp = self->resetAmp = 1.;
     self->currentAmp = self->lastAmp = 0.;
     self->withGUI = 0;
@@ -1441,13 +1446,22 @@ Server_init(Server *self, PyObject *args, PyObject *kwds)
     if (strlen(serverName) > 31) {
         self->serverName[31] = '\0';
     }
-    self->recpath = getenv("HOME");
-    if (self->recpath != NULL)
-        strncat(self->recpath, "/pyo_rec.wav", strlen("/pyo_rec.wav")); 
 
     return 0;
 }
 
+static PyObject *
+Server_setDefaultRecPath(Server *self, PyObject *args, PyObject *kwds)
+{
+    static char *kwlist[] = {"path", NULL};
+    
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "s", kwlist, &self->recpath))
+        return PyInt_FromLong(-1);
+
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+    
 static PyObject *
 Server_setInputDevice(Server *self, PyObject *arg)
 {
@@ -1493,6 +1507,17 @@ Server_setMidiInputDevice(Server *self, PyObject *arg)
     return Py_None;
 }
 
+static PyObject *
+Server_setMidiOutputDevice(Server *self, PyObject *arg)
+{
+	if (arg != NULL) {
+        if (PyInt_Check(arg))
+            self->midi_output = PyInt_AsLong(arg);
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 Server_setSamplingRate(Server *self, PyObject *arg)
 {
@@ -1727,42 +1752,82 @@ Server_pm_init(Server *self)
 
     pmerr = Pm_Initialize();
     if (pmerr) {
-        Server_warning(self, "PortMidi warning: could not initialize PortMidi: %s\n", Pm_GetErrorText(pmerr));
+        Server_warning(self, "Portmidi warning: could not initialize Portmidi: %s\n", Pm_GetErrorText(pmerr));
         self->withPortMidi = 0;
+        self->withPortMidiOut = 0;
         return -1;
     }    
     else {
-        Server_debug(self, "PortMidi initialized.\n");
+        Server_debug(self, "Portmidi initialized.\n");
         self->withPortMidi = 1;
+        self->withPortMidiOut = 1;
     }    
 
     if (self->withPortMidi == 1) {
         int num_devices = Pm_CountDevices();
         if (num_devices > 0) {
             if (self->midi_input == -1 || self->midi_input >= num_devices)
-                self->midi_input = 0;
+                self->midi_input = Pm_GetDefaultInputDeviceID();
+            Server_debug(self, "Midi input device : %d.\n", self->midi_input);
             const PmDeviceInfo *info = Pm_GetDeviceInfo(self->midi_input);
-            if (info->input) {
-                pmerr = Pm_OpenInput(&self->in, self->midi_input, NULL, 100, NULL, NULL);
-                if (pmerr) {
-                    Server_warning(self, 
-                                 "PortMidi warning: could not open midi input %d (%s): %s\nPortmidi closed\n",
+            if (info != NULL) {
+                if (info->input) {
+                    pmerr = Pm_OpenInput(&self->in, self->midi_input, NULL, 100, NULL, NULL);
+                    if (pmerr) {
+                        Server_warning(self, 
+                                 "Portmidi warning: could not open midi input %d (%s): %s\n",
                                  0, info->name, Pm_GetErrorText(pmerr));
+                        self->withPortMidi = 0;
+                    }    
+                    else
+                        Server_debug(self, "Midi input (%s) opened.\n", info->name);
+                }
+                else {
+                    Server_warning(self, "Portmidi warning: something wrong with midi input device!\n");
                     self->withPortMidi = 0;
-                    Pm_Terminate();
-                }    
-                else
-                    Server_debug(self, "Midi Input (%s) opened.\n", info->name);
+                }
             }
             else {
-                Server_warning(self, "PortMidi warning: Something wrong with midi device!\nPortmidi closed\n");
-                self->withPortMidi = 0;
+                    Server_warning(self, "Portmidi warning: no input device!\n");
+                    self->withPortMidi = 0;
+            }
+            
+            if (self->midi_output == -1 || self->midi_output >= num_devices)
+                self->midi_output = Pm_GetDefaultOutputDeviceID();
+            Server_debug(self, "Midi output device : %d.\n", self->midi_output);
+            const PmDeviceInfo *outinfo = Pm_GetDeviceInfo(self->midi_output);
+            if (outinfo != NULL) {
+                if (outinfo->output) {
+                    Pt_Start(1, 0, 0); /* start a timer with millisecond accuracy */
+                    pmerr = Pm_OpenOutput(&self->out, self->midi_output, NULL, 0, NULL, NULL, 1);
+                    if (pmerr) {
+                        Server_warning(self, 
+                                 "Portmidi warning: could not open midi output %d (%s): %s\n",
+                                 0, outinfo->name, Pm_GetErrorText(pmerr));
+                        self->withPortMidiOut = 0;
+                    }    
+                    else
+                        Server_debug(self, "Midi output (%s) opened.\n", outinfo->name);
+                }
+                else {
+                    Server_warning(self, "Portmidi warning: something wrong with midi output device!\n");
+                    self->withPortMidiOut = 0;
+                }
+            }
+            else {
+                    Server_warning(self, "Portmidi warning: no output device!\n");
+                    self->withPortMidi = 0;
+            }
+            
+            if (self->withPortMidi == 0 && self->withPortMidiOut == 0) {
                 Pm_Terminate();
-            }    
+                Server_warning(self, "Portmidi closed.\n");
+            }
         }    
         else {
-            Server_warning(self, "PortMidi warning: No midi device found!\nPortmidi closed\n");
+            Server_warning(self, "Portmidi warning: no midi device found!\nPortmidi closed.\n");
             self->withPortMidi = 0;
+            self->withPortMidiOut = 0;
             Pm_Terminate();
         }    
     }
@@ -2107,7 +2172,7 @@ Server_removeStream(Server *self, int id)
 PyObject *
 Server_changeStreamPosition(Server *self, PyObject *args)
 {
-    int err, i, rsid, csid, sid;
+    int i, rsid, csid, sid;
     Stream *ref_stream_tmp, *cur_stream_tmp, *stream_tmp;
 
     if (! PyArg_ParseTuple(args, "OO", &ref_stream_tmp, &cur_stream_tmp))
@@ -2135,13 +2200,35 @@ Server_changeStreamPosition(Server *self, PyObject *args)
     }
 
     Py_INCREF(cur_stream_tmp);
-    err = PyList_Insert(self->streams, i, (PyObject *)cur_stream_tmp);
+    PyList_Insert(self->streams, i, (PyObject *)cur_stream_tmp);
     self->stream_count++;
 
     Py_INCREF(Py_None);
     return Py_None;    
 }
 
+PyObject *
+Server_sendMidiNote(Server *self, PyObject *args)
+{
+    int pit, vel, chan, curtime;
+    PmEvent buffer[1];
+    PmTimestamp timestamp;
+
+    if (! PyArg_ParseTuple(args, "iiii", &pit, &vel, &chan, &timestamp))
+        return PyInt_FromLong(-1); 
+
+    curtime = Pt_Time();
+    buffer[0].timestamp = curtime + timestamp;
+    if (chan == 0)
+        buffer[0].message = Pm_Message(0x90, pit, vel);
+    else
+        buffer[0].message = Pm_Message(0x90 | (chan - 1), pit, vel);
+    Pm_Write(self->out, buffer, 1);
+
+    Py_INCREF(Py_None);
+    return Py_None;    
+}
+
 MYFLT *
 Server_getInputBuffer(Server *self) {
     return (MYFLT *)self->input_buffer;
@@ -2212,6 +2299,7 @@ static PyMethodDef Server_methods[] = {
     {"setOutputDevice", (PyCFunction)Server_setOutputDevice, METH_O, "Sets audio output device."},
     {"setInOutDevice", (PyCFunction)Server_setInOutDevice, METH_O, "Sets both audio input and output device."},
     {"setMidiInputDevice", (PyCFunction)Server_setMidiInputDevice, METH_O, "Sets MIDI input device."},
+    {"setMidiOutputDevice", (PyCFunction)Server_setMidiOutputDevice, METH_O, "Sets MIDI output device."},
     {"setSamplingRate", (PyCFunction)Server_setSamplingRate, METH_O, "Sets the server's sampling rate."},
     {"setBufferSize", (PyCFunction)Server_setBufferSize, METH_O, "Sets the server's buffer size."},
     {"setNchnls", (PyCFunction)Server_setNchnls, METH_O, "Sets the server's number of channels."},
@@ -2235,6 +2323,7 @@ static PyMethodDef Server_methods[] = {
                                                                 This is for internal use and must never be called by the user."},
     {"changeStreamPosition", (PyCFunction)Server_changeStreamPosition, METH_VARARGS, "Puts an audio stream before another in the stack. \
                                                                 This is for internal use and must never be called by the user."},
+    {"sendMidiNote", (PyCFunction)Server_sendMidiNote, METH_VARARGS, "Send a Midi note to Portmidi output stream."},
     {"getStreams", (PyCFunction)Server_getStreams, METH_NOARGS, "Returns the list of streams added to the server."},
     {"getSamplingRate", (PyCFunction)Server_getSamplingRate, METH_NOARGS, "Returns the server's sampling rate."},
     {"getNchnls", (PyCFunction)Server_getNchnls, METH_NOARGS, "Returns the server's current number of channels."},
@@ -2243,6 +2332,7 @@ static PyMethodDef Server_methods[] = {
     {"getIsBooted", (PyCFunction)Server_getIsBooted, METH_NOARGS, "Returns 1 if the server is booted, otherwise returns 0."},
     {"getIsStarted", (PyCFunction)Server_getIsStarted, METH_NOARGS, "Returns 1 if the server is started, otherwise returns 0."},
     {"getMidiActive", (PyCFunction)Server_getMidiActive, METH_NOARGS, "Returns 1 if midi callback is active, otherwise returns 0."},
+    {"_setDefaultRecPath", (PyCFunction)Server_setDefaultRecPath, METH_VARARGS|METH_KEYWORDS, "Sets the default recording path."},
     {NULL}  /* Sentinel */
 };
 
